@@ -1,4 +1,4 @@
-__version__ = '1.0.33'
+__version__ = '1.0.34'
 __author__ = 'arnold'
 
 import json
@@ -113,7 +113,8 @@ class TerraformQueryExtension(Extension):
         
         # Iterating over the outputs and returning the value of the output with the name that matches the name
         # passed in.
-        if name in current_state_version_outputs["attributes"]["name"]:
+        if any(d["attributes"]["name"] == name for d in current_state_version_outputs):
+        # if name in current_state_version_outputs["attributes"]["name"]:
             for output in current_state_version_outputs:
                 if(output["attributes"]["name"] == name):
                     if((value_name is not None) and (output["attributes"]["value"][value_name] is not None)):
@@ -122,5 +123,5 @@ class TerraformQueryExtension(Extension):
                         return output["attributes"]["value"]
                     else:
                         sys.exit("Value is None for attribute " +name)
-        elif name["attributes"]["name"] is None:
+        elif not any(d["attributes"]["name"] == name for d in current_state_version_outputs):
             sys.exit("Value is None for attribute = " +name)
